From 004739dc8e17da29f34d8457e9bf225b189f6a78 Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Fri, 15 May 2009 14:36:04 -0400
Subject: [PATCH] - typo + rename db_password_dsn to password_db_dsn

---
 plugins/password/password.php |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/plugins/password/password.php b/plugins/password/password.php
index f10c43c..75befc0 100644
--- a/plugins/password/password.php
+++ b/plugins/password/password.php
@@ -13,7 +13,7 @@
  * Configuration Items (config/main.inc.php):
  *   password_confirm_current - boolean to determine whether current password
  *     is required to change password. Defaults to FALSE.
  *   db_passwd_dsn - is the PEAR database DSN for performing the query. Defaults
  *     to the default databse setting in config/db.inc.php
  *   password_query - the SQL query used to change the password.
  *     If the SQL query is a SELECT it will return an error message in a row if unsuccessful
@@ -208,13 +208,14 @@
     if (!($sql = $cfg->get('password_query')))
       $sql = "SELECT update_passwd(%c, %u)";
 
-    if ($dsn = $cfg->get('db_passwd_dsn')) {
+    if ($dsn = $cfg->get('password_db_dsn')) {
       $db = new rcube_mdb2($dsn, '', FALSE);
       $db->set_debug((bool)$cfg->get('sql_debug'));
       $db->db_connect('w');
     } else {
       $db = rcmail::get_instance()->get_dbh();
     }
+
     if ($err = $db->is_error())
       return $err;
     
@@ -13,7 +13,7 @@
  *   password_confirm_current - boolean to determine whether current password
  *     is required to change password. Defaults to FALSE.
- *   db_passwd_dsn - is the PEAR database DSN for performing the query. Defaults
+ *   password_db_dsn - is the PEAR database DSN for performing the query. Defaults
  *     to the default databse setting in config/db.inc.php
  *   password_query - the SQL query used to change the password.

--
Gitblit v1.9.1